==> kdevelop-4.5.90.tar.xz: kdevelop-4.5.90/utils/okteta/kdevokteta.desktop.cmake <==
[Desktop Entry]
Type=Service

Name=Okteta Integration
Name[bs]=Okteta integracija
Name[ca]=Integració d'Okteta
Name[ca@valencia]=Integració d'Okteta
Name[cs]=Integrace Oktety
Name[da]=Okteta-integration
Name[de]=Integration von Okteta
Name[el]=Ενσωμάτωση Okteta
Name[en_GB]=Okteta Integration
Name[es]=Integración de Okteta
Name[et]=Okteta lõimimine
Name[fi]=Okteta-integraatio
Name[fr]=Intégration de Okteta
Name[ga]=Comhtháthú Okteta
Name[gl]=Integración do Okteta
Name[hu]=Okteta integráció
Name[it]=Integrazione Okteta
Name[kk]=Okteta-мен біріктіру
Name[km]=ការ​រួមបញ្ចូល Okteta
Name[nb]=Okteta-integrasjon
Name[nds]=Okteta-Inbinnen
Name[nl]=Okteta-integratie
Name[pl]=Integracja Okteta
Name[pt]=Integração com o Okteta
Name[pt_BR]=Integração com o Okteta
Name[ru]=Интеграция Okteta
Name[sk]=Integrácia Okteta
Name[sl]=Vgradnja Oktete
Name[sv]=Integrering med Okteta
Name[tr]=Okteta Bütünleştirmesi
Name[ug]=Okteta يۈرۈشلەشتۈرۈلۈشى
Name[uk]=Інтеграція з Okteta
Name[x-test]=xxOkteta Integrationxx
Name[zh_CN]=Okteta 集成
Name[zh_TW]=Okteta 整合
GenericName=Hex Editor Integration
GenericName[bs]=Integracija heksadekadnog uređivača
GenericName[ca]=Integració d'editor hexadecimal
GenericName[ca@valencia]=Integració d'editor hexadecimal
GenericName[cs]=Integrace hexa editoru
GenericName[da]=Integration af HeX-editor
GenericName[de]=Hex-Editor-Integration
GenericName[el]=Ενσωμάτωση κειμενογράφου δεκαεξαδικού συστήματος
GenericName[en_GB]=Hex Editor Integration
GenericName[es]=Integración del editor hexadecimal
GenericName[et]=Binaarfailide redaktori lõimimine
GenericName[fi]=Heksaeditori-integraatio
GenericName[fr]=Intégration d'un éditeur hexadécimal
GenericName[gl]=Integración do editor hexadecimal
GenericName[hu]=Hexa szerkesztő integráció
GenericName[it]=Integrazione editor esadecimale
GenericName[kk]=Оналтылық түрде өңдеу редакторымен біріктіру
GenericName[nb]=Integrasjon av en hex-redigerer
GenericName[nds]=Hex-Editor--Inbinnen
GenericName[nl]=Hexbewerker-integratie
GenericName[pl]=Integracja edytora szesnastkowego
GenericName[pt]=Integração com o Editor Hexadecimal
GenericName[pt_BR]=Integração com o editor hexadecimal
GenericName[ru]=Интеграция шестнадцатеричного редактора
GenericName[sk]=Integrácia hex editora
GenericName[sl]=Vgradnja šestnajstiškega urejevalnika
GenericName[sv]=Integrering av hexadecimaleditor
GenericName[tr]=Altılık Dosya Düzenleyici Bütünleştirmesi
GenericName[ug]=ئون ئالتىلىك سان تەھرىرلىگۈچى بىلەن يۈرۈشلەشتۈرۈلۈش
GenericName[uk]=Інтеграція з шістнадцятковим редактором
GenericName[x-test]=xxHex Editor Integrationxx
GenericName[zh_CN]=十六进制编辑器集成
GenericName[zh_TW]=十六進位資料編輯器整合
Comment=KDevelop Hex Editor based on Okteta
Comment[bs]=KDevelop heksadekadni uređivač baziran na Okteta
Comment[ca]=Editor hexadecimal de KDevelop basat en Okteta
Comment[ca@valencia]=Editor hexadecimal de KDevelop basat en Okteta
Comment[da]=KDevelop Hex-editor baseret på Okteta
Comment[de]=Auf Okteta basierender Hex-Editor für KDevelop
Comment[el]=Κειμενογράφος δεκαεξαδικού συστήματος του KDevelop με βάση το Okteta
Comment[en_GB]=KDevelop Hex Editor based on Okteta
Comment[es]=Editor hexadecimal de KDevelop basado en Okteta
Comment[et]=KDevelopi binaarfailide redaktor Okteta põhjal
Comment[fi]=KDevelopin Oktetaan perustuva heksaeditori
Comment[fr]=Éditeur hexadécimal pour KDevelop fondé sur Okteta
Comment[gl]=Editor hexadecimal do KDevelop baseado no Okteta
Comment[hu]=Az Oktetán alapuló KDevelop hexa szerkesztő
Comment[it]=Editor esadecimale di KDevelop basato su Okteta
Comment[kk]=Okteta негізіндегі KDevelop оналтылық редакторы
Comment[nb]=KDevelop Hex-redigerer basert på Okteta
Comment[nds]=Hex-Editor för KDevelop, op Okteta opbuut
Comment[nl]=KDevelop hex-bewerker gebaseerd op Okteta
Comment[pl]=Edytor szesnastkowy oparty o Okteta dla KDevelop 
Comment[pt]=Editor Hexadecimal para o KDevelop, baseado no Okteta
Comment[pt_BR]=Editor hexadecimal do KDevelop, baseado no Okteta
Comment[ru]=Шестнадцатеричный редактор в KDevelop на базе Okteta
Comment[sk]=Hex editor KDevelop založený na Okteta
Comment[sl]=Šestnajstiški urejevalnik, ki temelji na Okteti
Comment[sv]=KDevelop hexadecimaleditor baserad på Okteta
Comment[tr]=Okteta temelli KDevelop Altılık Dosya Düzenleyici
Comment[ug]=Okteta ئاساسىدىكى KDevelop ئون ئالتىلىك سان تەھرىرلىگۈچى
Comment[uk]=Шістнадцятковий редактор KDevelop, заснований на Okteta
Comment[x-test]=xxKDevelop Hex Editor based on Oktetaxx
Comment[zh_CN]=基于 Okteta 的 KDevelop 十六进制编辑器
Comment[zh_TW]=以 Okteta 為基礎的 KDevelop 十六進位資料編輯器
Icon=okteta
ServiceTypes=KDevelop/Plugin

X-KDE-Library=kdevokteta
X-KDE-PluginInfo-Name=kdevokteta
X-KDE-PluginInfo-Author=Friedrich W. H. Kossebau
X-KDE-PluginInfo-Email=kossebau@kde.org
X-KDE-PluginInfo-Version=0.1.0
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-Category=Utilities
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Category=Global
X-KDevelop-Mode=GUI

==> kdevelop-4.7.2.tar.xz: kdevelop-4.7.2/utils/okteta/kdevokteta.desktop.cmake <==
[Desktop Entry]
Type=Service

Name=Okteta Integration
Name[bs]=Okteta integracija
Name[ca]=Integració d'Okteta
Name[ca@valencia]=Integració d'Okteta
Name[cs]=Integrace Oktety
Name[da]=Okteta-integration
Name[de]=Integration von Okteta
Name[el]=Ενσωμάτωση Okteta
Name[en_GB]=Okteta Integration
Name[es]=Integración de Okteta
Name[et]=Okteta lõimimine
Name[fi]=Okteta-integraatio
Name[fr]=Intégration de Okteta
Name[ga]=Comhtháthú Okteta
Name[gl]=Integración do Okteta
Name[hu]=Okteta integráció
Name[it]=Integrazione Okteta
Name[kk]=Okteta-мен біріктіру
Name[km]=ការ​រួមបញ្ចូល Okteta
Name[nb]=Okteta-integrasjon
Name[nds]=Okteta-Inbinnen
Name[nl]=Okteta-integratie
Name[pl]=Integracja Okteta
Name[pt]=Integração com o Okteta
Name[pt_BR]=Integração com o Okteta
Name[ru]=Интеграция Okteta
Name[sk]=Integrácia Okteta
Name[sl]=Vgradnja Oktete
Name[sv]=Integrering med Okteta
Name[tr]=Okteta Bütünleştirmesi
Name[ug]=Okteta يۈرۈشلەشتۈرۈلۈشى
Name[uk]=Інтеграція з Okteta
Name[x-test]=xxOkteta Integrationxx
Name[zh_CN]=Okteta 集成
Name[zh_TW]=Okteta 整合
GenericName=Hex Editor Integration
GenericName[bs]=Integracija heksadekadnog uređivača
GenericName[ca]=Integració d'editor hexadecimal
GenericName[ca@valencia]=Integració d'editor hexadecimal
GenericName[cs]=Integrace hexa editoru
GenericName[da]=Integration af HeX-editor
GenericName[de]=Hex-Editor-Integration
GenericName[el]=Ενσωμάτωση κειμενογράφου δεκαεξαδικού συστήματος
GenericName[en_GB]=Hex Editor Integration
GenericName[es]=Integración del editor hexadecimal
GenericName[et]=Binaarfailide redaktori lõimimine
GenericName[fi]=Heksaeditori-integraatio
GenericName[fr]=Intégration d'un éditeur hexadécimal
GenericName[gl]=Integración do editor hexadecimal
GenericName[hu]=Hexa szerkesztő integráció
GenericName[it]=Integrazione editor esadecimale
GenericName[kk]=Оналтылық түрде өңдеу редакторымен біріктіру
GenericName[nb]=Integrasjon av en hex-redigerer
GenericName[nds]=Hex-Editor--Inbinnen
GenericName[nl]=Hexbewerker-integratie
GenericName[pl]=Integracja edytora szesnastkowego
GenericName[pt]=Integração com o Editor Hexadecimal
GenericName[pt_BR]=Integração com o editor hexadecimal
GenericName[ru]=Интеграция шестнадцатеричного редактора
GenericName[sk]=Integrácia hex editora
GenericName[sl]=Vgradnja šestnajstiškega urejevalnika
GenericName[sv]=Integrering av hexadecimaleditor
GenericName[tr]=Altılık Dosya Düzenleyici Bütünleştirmesi
GenericName[ug]=ئون ئالتىلىك سان تەھرىرلىگۈچى بىلەن يۈرۈشلەشتۈرۈلۈش
GenericName[uk]=Інтеграція з шістнадцятковим редактором
GenericName[x-test]=xxHex Editor Integrationxx
GenericName[zh_CN]=十六进制编辑器集成
GenericName[zh_TW]=十六進位資料編輯器整合
Comment=KDevelop Hex Editor based on Okteta
Comment[bs]=KDevelop heksadekadni uređivač baziran na Okteta
Comment[ca]=Editor hexadecimal de KDevelop basat en Okteta
Comment[ca@valencia]=Editor hexadecimal de KDevelop basat en Okteta
Comment[da]=KDevelop Hex-editor baseret på Okteta
Comment[de]=Auf Okteta basierender Hex-Editor für KDevelop
Comment[el]=Κειμενογράφος δεκαεξαδικού συστήματος του KDevelop με βάση το Okteta
Comment[en_GB]=KDevelop Hex Editor based on Okteta
Comment[es]=Editor hexadecimal de KDevelop basado en Okteta
Comment[et]=KDevelopi binaarfailide redaktor Okteta põhjal
Comment[fi]=KDevelopin Oktetaan perustuva heksaeditori
Comment[fr]=Éditeur hexadécimal pour KDevelop fondé sur Okteta
Comment[gl]=Editor hexadecimal do KDevelop baseado no Okteta
Comment[hu]=Az Oktetán alapuló KDevelop hexa szerkesztő
Comment[it]=Editor esadecimale di KDevelop basato su Okteta
Comment[kk]=Okteta негізіндегі KDevelop оналтылық редакторы
Comment[nb]=KDevelop Hex-redigerer basert på Okteta
Comment[nds]=Hex-Editor för KDevelop, op Okteta opbuut
Comment[nl]=KDevelop hex-bewerker gebaseerd op Okteta
Comment[pl]=Edytor szesnastkowy oparty na Okteta dla KDevelop 
Comment[pt]=Editor Hexadecimal para o KDevelop, baseado no Okteta
Comment[pt_BR]=Editor hexadecimal do KDevelop, baseado no Okteta
Comment[ru]=Шестнадцатеричный редактор в KDevelop на базе Okteta
Comment[sk]=Hex editor KDevelop založený na Okteta
Comment[sl]=Šestnajstiški urejevalnik, ki temelji na Okteti
Comment[sv]=KDevelop hexadecimaleditor baserad på Okteta
Comment[tr]=Okteta temelli KDevelop Altılık Dosya Düzenleyici
Comment[ug]=Okteta ئاساسىدىكى KDevelop ئون ئالتىلىك سان تەھرىرلىگۈچى
Comment[uk]=Шістнадцятковий редактор KDevelop, заснований на Okteta
Comment[x-test]=xxKDevelop Hex Editor based on Oktetaxx
Comment[zh_CN]=基于 Okteta 的 KDevelop 十六进制编辑器
Comment[zh_TW]=以 Okteta 為基礎的 KDevelop 十六進位資料編輯器
Icon=okteta
ServiceTypes=KDevelop/Plugin

X-KDE-Library=kdevokteta
X-KDE-PluginInfo-Name=kdevokteta
X-KDE-PluginInfo-Author=Friedrich W. H. Kossebau
X-KDE-PluginInfo-Email=kossebau@kde.org
X-KDE-PluginInfo-Version=0.1.0
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-Category=Utilities
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Category=Global
X-KDevelop-Mode=GUI
